﻿using System;
using System.Windows.Forms;

namespace ShutdownTimer.DesktopExtension
{
    static class Program
    {
        [STAThread]
        static void Main(string[] args)
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);

            if (args.Length == 0)
            {
                // Throw error as there was no arg supplied
                MessageBox.Show("The Desktop Extension got executed without any arguments!\n\n" +
                    "You are seeing this because something in the Shutdown Timer app didn't quite work (presumably executing the power action).\n" +
                    "Please see if there is any problem with the app.", "Shutdown Timer Desktop Extension",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            else if (args.Length == 3)
            {
                // There must be 3 arguments as 2 other arguments are supplied when launched from a UWP app with FullTrustProcessLauncher and the third one is the one we have specified in the appxmanifest
                ExecuteAction(args[2]); // Execute the power action
            }
            else
            {
                // Throw error as there were too many args supplied
                MessageBox.Show("The Desktop Extension got executed with too many arguments!\n\n" +
                    "You are seeing this because something in the Shutdown Timer app didn't quite work (presumably executing the power action).\n" +
                    "Please see if there is any problem with the app.", "Shutdown Timer Desktop Extension",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            Application.Exit();
        }

        static void ExecuteAction(string arg)
        {
            arg = arg.ToLower();

            switch (arg)
            {
                case "shutdown":
                    ExitWindows.Shutdown(true);
                    break;

                case "restart":
                    ExitWindows.Reboot(true);
                    break;

                case "hibernate":
                    Application.SetSuspendState(PowerState.Hibernate, true, true);
                    break;

                case "sleep":
                    Application.SetSuspendState(PowerState.Suspend, true, true);
                    break;

                case "logout":
                    ExitWindows.LogOff(true);
                    break;

                case "lock":
                    ExitWindows.Lock();
                    break;

                default:
                    MessageBox.Show("The Desktop Extension got executed with an unknown argument!\n\n" +
                    "You are seeing this because something in the Shutdown Timer app didn't quite work (presumably executing the power action).\n" +
                    "Please see if there is any problem with the app.", "Shutdown Timer Desktop Extension",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
                    break;
            }
        }
    }
}
