﻿using System;
using System.Threading.Tasks;

using Microsoft.Toolkit.Uwp.Notifications;

using ShutdownTimer.Activation;

using Windows.ApplicationModel.Activation;
using Windows.UI.Notifications;

namespace ShutdownTimer.Services
{
    internal partial class ToastNotificationsService : ActivationHandler<ToastNotificationActivatedEventArgs>
    {
        public void ShowTimeLeftNotification(string action, string timeLeftFormatted)
        {
            try
            {
                var content = new ToastContent()
                {
                    Launch = "ToastContentActivationParams",

                    Visual = new ToastVisual()
                    {
                        BindingGeneric = new ToastBindingGeneric()
                        {
                            Children =
                            {
                                new AdaptiveText()
                                {
                                    Text = "Your time is running out!"
                                },

                                new AdaptiveText()
                                {
                                    Text = "Your " + action + " timer for " + timeLeftFormatted + " is getting active in five minutes."
                                }
                            }
                        }
                    },

                    Actions = new ToastActionsCustom()
                    {
                        Buttons =
                        {
                            new ToastButtonDismiss("OK")
                        }
                    }
                };

                var toast = new ToastNotification(content.GetXml())
                {
                    Tag = "ToastTag"
                };

                ToastNotificationManager.CreateToastNotifier().Show(toast);
            }
            catch (Exception)
            {
                // TODO WTS: Adding ToastNotification can fail in rare conditions, please handle exceptions as appropriate to your scenario.
            }
        }

        protected override async Task HandleInternalAsync(ToastNotificationActivatedEventArgs args)
        {
            //// TODO WTS: Handle activation from toast notification
            //// More details at https://docs.microsoft.com/windows/uwp/design/shell/tiles-and-notifications/send-local-toast

            await Task.CompletedTask;
        }
    }
}
